@@ -1,7 +1,7 @@
 package Sah::Schemas::Float;
 
-our $DATE = '2018-06-04'; # DATE
-our $VERSION = '0.002'; # VERSION
+our $DATE = '2019-04-08'; # DATE
+our $VERSION = '0.003'; # VERSION
 
 1;
 # ABSTRACT: Sah schemas for various floating types
@@ -18,12 +18,16 @@ Sah::Schemas::Float - Sah schemas for various floating types
 
 =head1 VERSION
 
-This document describes version 0.002 of Sah::Schemas::Float (from Perl distribution Sah-Schemas-Float), released on 2018-06-04.
+This document describes version 0.003 of Sah::Schemas::Float (from Perl distribution Sah-Schemas-Float), released on 2019-04-08.
 
 =head1 SAH SCHEMAS
 
 =over
 
+=item * L<negfloat|Sah::Schema::negfloat>
+
+Negative float.
+
 =item * L<percent|Sah::Schema::percent>
 
 A float.
@@ -33,6 +37,13 @@ percent sign is optional, but the number is always interpreted as percent, e.g.
 "1" is interpreted as 1% (0.01).
 
 
+=item * L<posfloat|Sah::Schema::posfloat>
+
+Positive float.
+
+
+
+
 =item * L<share|Sah::Schema::share>
 
 A float between 0 and 1.
@@ -48,6 +59,13 @@ to mean "0.01" or "1%") use of this type is discouraged. Use
 L<Sah::Schema::percent> instead.
 
 
+=item * L<ufloat|Sah::Schema::ufloat>
+
+Non-negative float.
+
+See also C<posfloat> for floats that are larger than 0.
+
+
 =back
 
 =head1 HOMEPAGE
@@ -78,7 +96,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2018 by perlancar@cpan.org.
+This software is copyright (c) 2019, 2018 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
